@@ -23,7 +23,7 @@
 #define INCLUDED_TWITTER_H
 
 #include <glib.h>
-#include "http.h"
+#include "microfeedhttp.h"
 #include "ui.h"
 
 typedef enum {
@@ -34,7 +34,7 @@ typedef enum {
 
 extern ViewItemSource twitter_item_source;
 
-gboolean twitter_handle_marked_item(ViewAddingSession* session, Http* http, gchar* unique_id, gchar* url);
+gboolean twitter_handle_marked_item(ViewAddingSession* session, MicrofeedHttp* http, gchar* unique_id, gchar* url);
 gboolean twitter_send(const gchar* text);
 void twitter_update_contacts_view(View* view);
 void twitter_update_explore_view(View* view);
