@@ -55,7 +55,7 @@ static void init_actions();
 static void init_icon_factory();
 static void init_menu();
 static void init_toolbar();
-static void insert_into_toolbar(GtkToolbar* toolbar, GtkAction* action);
+static void insert_into_toolbar(GtkToolbar* toolbar, GtkAction* action, gboolean insert_separator);
 static void menu_position_func(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer user_data);
 static gboolean on_about_button_release_event(GtkWidget* widget, GdkEventButton* event, View* view);
 static void on_add_comment_activate(GtkAction* action, gpointer user_data);
@@ -100,13 +100,13 @@ static GtkAction* open_sent_direct_messages_action;
 static GtkAction* open_replies_action;
 static GtkAction* settings_action;
 static GtkAction* about_action;
-static GtkAction* change_location_action;
+/* static GtkAction* change_location_action; */
 static GtkToggleAction* show_toolbar_action;
 static GtkToggleAction* show_scrollbar_action;
 static GtkToggleAction* new_item_notification_action;
 static GtkAction* close_this_window_action;
 static GtkAction* close_all_windows_action;
-static GtkWidget* location_label;
+/* static GtkWidget* location_label; */
 #ifdef MAUKU_BACKTRACE_UPLOADS_ENABLED
 static GtkAction* upload_backtrace_action;
 #endif
@@ -148,11 +148,11 @@ void ui_popup_menu() {
 	               gtk_get_current_event_time());
 
 }
-
+/*
 void ui_set_location(const gchar* location_text) {
 	gtk_label_set_text(GTK_LABEL(location_label), location_text);
 }
-
+*/
 void ui_set_sensitive_actions(UiSensitiveActionType sensitive_actions) {
 	gtk_action_set_sensitive(write_something_action, sensitive_actions & UI_SENSITIVE_ACTION_WRITE_SOMETHING);
 	gtk_action_set_sensitive(send_action, sensitive_actions & UI_SENSITIVE_ACTION_SEND);
@@ -188,7 +188,6 @@ static void add_icon_set_into_icon_factory(GtkIconFactory* icon_factory, const g
 	
 	for (i = 0; sizes[i]; i++) {
 		s = g_strconcat(DATADIR "/icons/hicolor/", sizes[i], "/hildon/", stock_id, (i ? ".png" : ".svg"), NULL);
-		printf("%s\n", s);
 		if ((pixbuf = gdk_pixbuf_new_from_file(s, NULL))) {
 			if (!icon_set) {
 				icon_set = gtk_icon_set_new_from_pixbuf(pixbuf);
@@ -248,9 +247,10 @@ static void init_actions() {
 	about_action = gtk_action_new("about", "About...", NULL, NULL);
 	g_signal_connect(about_action, "activate", G_CALLBACK(show_about_dialog), NULL);
 
+/*
 	change_location_action = gtk_action_new("change_location", "Change location...", NULL, MAUKU_STOCK_LOCATION_CHANGE);
 	g_signal_connect(change_location_action, "activate", G_CALLBACK(jaiku_change_location), NULL);
-
+*/
 	show_toolbar_action = gtk_toggle_action_new("show_toolbar", "Show toolbar", NULL, NULL);
 	gtk_toggle_action_set_active(show_toolbar_action, gconf_client_get_bool(gconf, MAUKU_GCONF_KEY_SHOW_TOOLBAR, NULL));
 	g_signal_connect(show_toolbar_action, "toggled", G_CALLBACK(on_toggle_action_toggled), MAUKU_GCONF_KEY_SHOW_TOOLBAR);
@@ -280,7 +280,7 @@ static void init_icon_factory() {
 	
 	icon_factory = gtk_icon_factory_new();
 	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_CONTACTS);
-	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_LOCATION_CHANGE);
+/*	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_LOCATION_CHANGE); */
 	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_MAIL_MESSAGE_NEW);
 	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_OVERVIEW);
 	add_icon_set_into_icon_factory(icon_factory, MAUKU_STOCK_VIEW_REFRESH);
@@ -344,9 +344,9 @@ static void init_menu() {
 	gtk_menu_shell_append(GTK_MENU_SHELL(submenu), item = gtk_action_create_menu_item(about_action));
 	gtk_widget_modify_font(gtk_bin_get_child(GTK_BIN(item)), font);
 
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item = gtk_action_create_menu_item(change_location_action));
+/*	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item = gtk_action_create_menu_item(change_location_action));
 	gtk_widget_modify_font(gtk_bin_get_child(GTK_BIN(item)), font);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), gtk_separator_menu_item_new());
+*/	gtk_menu_shell_append(GTK_MENU_SHELL(menu), gtk_separator_menu_item_new());
 
 	item = gtk_menu_item_new_with_label("Show");
 	gtk_widget_modify_font(gtk_bin_get_child(GTK_BIN(item)), font);
@@ -387,12 +387,12 @@ static void init_toolbar() {
 
 	toolbar = GTK_TOOLBAR(gtk_toolbar_new());
 	
-	insert_into_toolbar(toolbar, update_action);
-	insert_into_toolbar(toolbar, write_something_action);
-	insert_into_toolbar(toolbar, open_overview_action);
-	insert_into_toolbar(toolbar, open_contacts_action);
+	insert_into_toolbar(toolbar, update_action, TRUE);
+	insert_into_toolbar(toolbar, write_something_action, TRUE);
+	insert_into_toolbar(toolbar, open_overview_action, TRUE);
+	insert_into_toolbar(toolbar, open_contacts_action, FALSE);
 
-	item = GTK_TOOL_ITEM(gtk_action_create_tool_item(change_location_action));
+/*	item = GTK_TOOL_ITEM(gtk_action_create_tool_item(change_location_action));
 	gtk_tool_item_set_expand(item, TRUE);
 	gtk_toolbar_insert(toolbar, item, -1);
 
@@ -406,23 +406,25 @@ static void init_toolbar() {
 	gtk_misc_set_alignment(GTK_MISC(location_label), 0.0, 0.5);
 	gtk_container_add(GTK_CONTAINER(item), location_label);
 	gtk_toolbar_insert(toolbar, item, -1);
-
+*/
 	hildon_program_set_common_toolbar(hildon_program_get_instance(), toolbar);
 
 	gconf_client_notify_add(gconf, MAUKU_GCONF_KEY_SHOW_TOOLBAR, on_show_toolbar_notify, toolbar, NULL, NULL);
 	gconf_client_notify(gconf, MAUKU_GCONF_KEY_SHOW_TOOLBAR);
 }
 
-static void insert_into_toolbar(GtkToolbar* toolbar, GtkAction* action) {
+static void insert_into_toolbar(GtkToolbar* toolbar, GtkAction* action, gboolean append_separator) {
 	GtkToolItem* item;
 
 	item = GTK_TOOL_ITEM(gtk_action_create_tool_item(action));
 	gtk_tool_item_set_expand(item, TRUE);
 	gtk_toolbar_insert(toolbar, item, -1);
-	item = gtk_separator_tool_item_new();
-	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(item), FALSE);
-	gtk_tool_item_set_expand(item, TRUE);
-	gtk_toolbar_insert(toolbar, item, -1);
+	if (append_separator) {
+		item = gtk_separator_tool_item_new();
+		gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(item), FALSE);
+		gtk_tool_item_set_expand(item, TRUE);
+		gtk_toolbar_insert(toolbar, item, -1);
+	}
 }
 
 static void menu_position_func(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer user_data) {
@@ -513,7 +515,7 @@ static void on_open_overview_activate(GtkAction* action, gpointer user_data) {
 		 UI_SENSITIVE_ACTION_ALL & ~(UI_SENSITIVE_ACTION_OPEN_OVERVIEW | UI_SENSITIVE_ACTION_ADD_COMMENT),
 		 update_overview, NULL);
 		view_set_user_data(overview, "twitter:url", "http://twitter.com/statuses/friends_timeline.json", NULL);
-		if (http_is_connected()) {
+		if (network_is_connected()) {
 			view_start_update(overview, TRUE);
 		}
 	}
